@@ -1,5 +1,5 @@
 ## ----load-lib, echo=FALSE-----------------------------------------------------
-library("PKPDsim")
+library(PKPDsim)
 
 ## ----output-------------------------------------------------------------------
 mod <- new_ode_model(code = "
@@ -24,17 +24,17 @@ res <- sim(
   ode = mod, 
   parameters = par, 
   regimen = reg, 
-  only_obs = T
+  only_obs = TRUE
 )
 
 ## ----parameters-vars-covs-----------------------------------------------------
 mod_1cmt_iv <- new_ode_model("pk_1cmt_iv")
 p <- list(CL = 5, V = 50)
-reg <- new_regimen (amt = 100, n = 4, interval = 12, type = "bolus",  cmt=1)
+reg <- new_regimen(amt = 100, n = 4, interval = 12, type = "bolus",  cmt = 1)
 cov_table <- data.frame(
   id  = c(1, 1, 2, 3),
   WT  = c(40, 45, 50, 60),
-  SCR = c(50, 150, 90,110),
+  SCR = c(50, 150, 90, 110),
   t   = c(0, 5, 0, 0)
 )
 
@@ -45,8 +45,8 @@ dat <- sim(
   covariates_table = cov_table,
   covariates_implementation = list(SCR = "interpolate"),
   n_ind = 3,
-  only_obs = T,
-  output_include = list(parameters = TRUE, covariates=TRUE)
+  only_obs = TRUE,
+  output_include = list(parameters = TRUE, covariates = TRUE)
 )
 head(dat)
 
